@@ -72,7 +72,7 @@ export function initializeInput($el, $actionsEl, $copyAsCurlEl, output, openDocu
 
   let CURRENT_REQ_ID = 0;
 
-  function sendCurrentRequestToES() {
+  function sendCurrentRequestToES(addedToHistoryCb) {
 
     const reqId = ++CURRENT_REQ_ID;
 
@@ -129,19 +129,25 @@ export function initializeInput($el, $actionsEl, $copyAsCurlEl, output, openDocu
             ((xhr.status >= 200 && xhr.status < 300) || xhr.status === 404);
 
           if (isSuccess) {
-            if (xhr.status !== 404) {
+            if (xhr.status !== 404 && settings.getPolling()) {
               // If the user has submitted a request against ES, something in the fields, indices, aliases,
-              // or templates may have changed, so we'll need to update this data.
+              // or templates may have changed, so we'll need to update this data. Assume that if
+              // the user disables polling they're trying to optimize performance or otherwise
+              // preserve resources, so they won't want this request sent either.
               mappings.retrieveAutoCompleteInfo();
             }
 
             // we have someone on the other side. Add to history
             history.addToHistory(esPath, esMethod, esData);
+            if (addedToHistoryCb) {
+              addedToHistoryCb();
+            }
 
             let value = xhr.responseText;
             const mode = modeForContentType(xhr.getAllResponseHeaders('Content-Type') || '');
 
-            if (mode === null || mode === 'application/json') {
+            // Apply triple quotes to output.
+            if (settings.getTripleQuotes() && (mode === null || mode === 'application/json')) {
               // assume json - auto pretty
               try {
                 value = utils.expandLiteralStrings(value);
@@ -209,7 +215,7 @@ export function initializeInput($el, $actionsEl, $copyAsCurlEl, output, openDocu
   input.commands.addCommand({
     name: 'send to elasticsearch',
     bindKey: { win: 'Ctrl-Enter', mac: 'Command-Enter' },
-    exec: sendCurrentRequestToES
+    exec: () => sendCurrentRequestToES()
   });
   input.commands.addCommand({
     name: 'open documentation',
