@@ -48,12 +48,15 @@ const k7Breadcrumbs = ($route) => [
 ];
 
 uiRoutes
-  .when('/doc/:indexPattern/:index/:type/:id', {
+  // the old, pre 8.0 route, no longer used, keep it to stay compatible
+  // somebody might have bookmarked his favorite log messages
+  .when('/doc/:indexPattern/:index/:type', {
     template: html,
     resolve: resolveIndexPattern,
     k7Breadcrumbs
   })
-  .when('/doc/:indexPattern/:index/:type', {
+  //the new route, es 7 deprecated types, es 8 removed them
+  .when('/doc/:indexPattern/:index', {
     template: html,
     resolve: resolveIndexPattern,
     k7Breadcrumbs
@@ -73,7 +76,6 @@ app.controller('doc', function ($scope, $route, es) {
     body: {
       query: {
         ids: {
-          type: $route.current.params.type,
           values: [$route.current.params.id]
         }
       },
