@@ -57,6 +57,7 @@ class FieldUI extends PureComponent {
     setting: PropTypes.object.isRequired,
     save: PropTypes.func.isRequired,
     clear: PropTypes.func.isRequired,
+    enableSaving: PropTypes.bool.isRequired,
   }
 
   constructor(props) {
@@ -283,6 +284,34 @@ class FieldUI extends PureComponent {
     });
   }
 
+  showPageReloadToast = () => {
+    if (this.props.setting.requiresPageReload) {
+      toastNotifications.add({
+        title: this.props.intl.formatMessage({
+          id: 'kbn.management.settings.field.requiresPageReloadToastDescription',
+          defaultMessage: 'Please reload the page for the "{settingName}" setting to take effect.',
+        }, {
+          settingName: this.props.setting.displayName || this.props.setting.name,
+        }),
+        text: (
+          <>
+            <EuiFlexGroup justifyContent="flexEnd" gutterSize="s">
+              <EuiFlexItem grow={false}>
+                <EuiButton size="s" onClick={() => window.location.reload()}>
+                  {this.props.intl.formatMessage({
+                    id: 'kbn.management.settings.field.requiresPageReloadToastButtonLabel',
+                    defaultMessage: 'Reload page'
+                  })}
+                </EuiButton>
+              </EuiFlexItem>
+            </EuiFlexGroup>
+          </>
+        ),
+        color: 'success',
+      });
+    }
+  }
+
   saveEdit = async () => {
     const { name, defVal, type } = this.props.setting;
     const { changeImage, savedValue, unsavedValue, isJsonArray } = this.state;
@@ -314,6 +343,8 @@ class FieldUI extends PureComponent {
         await this.props.save(name, valueToSave);
       }
 
+      this.showPageReloadToast();
+
       if (changeImage) {
         this.cancelChangeImage();
       }
@@ -334,6 +365,7 @@ class FieldUI extends PureComponent {
     this.setLoading(true);
     try {
       await this.props.clear(name);
+      this.showPageReloadToast();
       this.cancelChangeImage();
       this.clearError();
     } catch (e) {
@@ -349,6 +381,7 @@ class FieldUI extends PureComponent {
   }
 
   renderField(setting) {
+    const { enableSaving } = this.props;
     const { loading, changeImage, unsavedValue } = this.state;
     const { name, value, type, options, optionLabels = {}, isOverridden, ariaName } = setting;
 
@@ -369,7 +402,7 @@ class FieldUI extends PureComponent {
             )}
             checked={!!unsavedValue}
             onChange={this.onFieldChange}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
             aria-label={ariaName}
@@ -389,7 +422,7 @@ class FieldUI extends PureComponent {
               height="auto"
               minLines={6}
               maxLines={30}
-              isReadOnly={isOverridden}
+              isReadOnly={isOverridden || !enableSaving}
               setOptions={{
                 showLineNumbers: false,
                 tabSize: 2,
@@ -414,7 +447,7 @@ class FieldUI extends PureComponent {
         } else {
           return (
             <EuiFilePicker
-              disabled={loading || isOverridden}
+              disabled={loading || isOverridden || !enableSaving}
               onChange={this.onImageChange}
               accept=".jpg,.jpeg,.png"
               ref={(input) => { this.changeImageForm = input; }}
@@ -436,7 +469,7 @@ class FieldUI extends PureComponent {
             })}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -448,7 +481,7 @@ class FieldUI extends PureComponent {
             value={unsavedValue}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -460,7 +493,7 @@ class FieldUI extends PureComponent {
             value={unsavedValue}
             onChange={this.onFieldChange}
             isLoading={loading}
-            disabled={loading || isOverridden}
+            disabled={loading || isOverridden || !enableSaving}
             onKeyDown={this.onFieldKeyDown}
             data-test-subj={`advancedSetting-editField-${name}`}
           />
@@ -484,10 +517,11 @@ class FieldUI extends PureComponent {
       );
     }
 
+    const canUpdateSetting = this.props.enableSaving;
     const defaultLink = this.renderResetToDefaultLink(setting);
     const imageLink = this.renderChangeImageLink(setting);
 
-    if (defaultLink || imageLink) {
+    if (canUpdateSetting && (defaultLink || imageLink)) {
       return (
         <span>
           {defaultLink}
