@@ -21,7 +21,6 @@ import './editor/editor';
 import { i18n } from '@kbn/i18n';
 import './saved_visualizations/_saved_vis';
 import './saved_visualizations/saved_visualizations';
-import 'ui/filter_bar';
 import uiRoutes from 'ui/routes';
 import 'ui/capabilities/route_setup';
 import visualizeListingTemplate from './listing/visualize_listing.html';
@@ -30,6 +29,10 @@ import { VisualizeConstants } from './visualize_constants';
 import { FeatureCatalogueRegistryProvider, FeatureCatalogueCategory } from 'ui/registry/feature_catalogue';
 import { getLandingBreadcrumbs, getWizardStep1Breadcrumbs } from './breadcrumbs';
 
+import { data } from 'plugins/data/setup';
+data.search.loadLegacyDirectives();
+data.filter.loadLegacyDirectives();
+
 uiRoutes
   .defaults(/visualize/, {
     requireDefaultIndex: true,
