@@ -24,30 +24,24 @@
 import PropTypes from 'prop-types';
 
 import React, { Component } from 'react';
-import tickFormatter from './lib/tick_formatter';
-import convertSeriesToVars from './lib/convert_series_to_vars';
+import { tickFormatter } from './lib/tick_formatter';
+import { convertSeriesToVars } from './lib/convert_series_to_vars';
 import _ from 'lodash';
 import 'brace/mode/markdown';
 import 'brace/theme/github';
 
-import {
-  EuiText,
-  EuiCodeBlock,
-  EuiSpacer,
-  EuiTitle,
-  EuiCodeEditor,
-} from '@elastic/eui';
+import { EuiText, EuiCodeBlock, EuiSpacer, EuiTitle, EuiCodeEditor } from '@elastic/eui';
 
 import { FormattedMessage } from '@kbn/i18n/react';
 
-class MarkdownEditor extends Component {
+export class MarkdownEditor extends Component {
   state = {
     visData: null,
   };
   subscription = null;
 
   componentDidMount() {
-    if(this.props.visData$) {
+    if (this.props.visData$) {
       this.subscription = this.props.visData$.subscribe(visData => {
         this.setState({ visData });
       });
@@ -55,18 +49,18 @@ class MarkdownEditor extends Component {
   }
 
   componentWillUnmount() {
-    if(this.subscription) {
+    if (this.subscription) {
       this.subscription.unsubscribe();
     }
   }
 
-  handleChange = (value) => {
+  handleChange = value => {
     this.props.onChange({ markdown: value });
-  }
+  };
 
-  handleOnLoad = (ace) => {
+  handleOnLoad = ace => {
     this.ace = ace;
-  }
+  };
 
   handleVarClick(snippet) {
     return () => {
@@ -158,13 +152,17 @@ class MarkdownEditor extends Component {
                 {handlebarLink} on the available expressions."
                 values={{
                   handlebarLink: (
-                    <a href="http://handlebarsjs.com/expressions.html" target="_BLANK" rel="noreferrer noopener">
+                    <a
+                      href="http://handlebarsjs.com/expressions.html"
+                      target="_BLANK"
+                      rel="noreferrer noopener"
+                    >
                       <FormattedMessage
                         id="tsvb.markdownEditor.howUseVariablesInMarkdownDescription.documentationLinkText"
                         defaultMessage="Click here for documentation"
                       />
                     </a>
-                  )
+                  ),
                 }}
               />
             </p>
@@ -173,16 +171,10 @@ class MarkdownEditor extends Component {
             <thead>
               <tr>
                 <th scope="col">
-                  <FormattedMessage
-                    id="tsvb.markdownEditor.nameLabel"
-                    defaultMessage="Name"
-                  />
+                  <FormattedMessage id="tsvb.markdownEditor.nameLabel" defaultMessage="Name" />
                 </th>
                 <th scope="col">
-                  <FormattedMessage
-                    id="tsvb.markdownEditor.valueLabel"
-                    defaultMessage="Value"
-                  />
+                  <FormattedMessage id="tsvb.markdownEditor.valueLabel" defaultMessage="Value" />
                 </th>
               </tr>
             </thead>
@@ -190,7 +182,11 @@ class MarkdownEditor extends Component {
           </table>
 
           {rows.length === 0 && (
-            <EuiTitle size="xxs" className="tsvbMarkdownVariablesTable__noVariables" data-test-subj="tvbMarkdownEditor__noVariables">
+            <EuiTitle
+              size="xxs"
+              className="tsvbMarkdownVariablesTable__noVariables"
+              data-test-subj="tvbMarkdownEditor__noVariables"
+            >
               <span>
                 <FormattedMessage
                   id="tsvb.markdownEditor.noVariablesAvailableDescription"
@@ -208,7 +204,7 @@ class MarkdownEditor extends Component {
                 id="tsvb.markdownEditor.howToAccessEntireTreeDescription"
                 defaultMessage="There is also a special variable named {all} which you can use to access the entire tree. This is useful for
                 creating lists with data from a group by:"
-                values={{ all: (<code>_all</code>) }}
+                values={{ all: <code>_all</code> }}
               />
             </p>
           </EuiText>
@@ -234,5 +230,3 @@ MarkdownEditor.propTypes = {
   dateFormat: PropTypes.string,
   visData$: PropTypes.object,
 };
-
-export default MarkdownEditor;
