@@ -19,13 +19,13 @@
 
 import React, { Component } from 'react';
 import PropTypes from 'prop-types';
-import FieldSelect from '../aggs/field_select';
-import SeriesEditor from '../series_editor';
+import { FieldSelect } from '../aggs/field_select';
+import { SeriesEditor } from '../series_editor';
 import { IndexPattern } from '../index_pattern';
-import createTextHandler from '../lib/create_text_handler';
+import { createTextHandler } from '../lib/create_text_handler';
 import { get } from 'lodash';
 import uuid from 'uuid';
-import YesNo from '../yes_no';
+import { YesNo } from '../yes_no';
 import {
   htmlIdGenerator,
   EuiTabs,
@@ -43,9 +43,12 @@ import {
   EuiText,
 } from '@elastic/eui';
 import { FormattedMessage } from '@kbn/i18n/react';
-
-class TablePanelConfig extends Component {
-
+import { Storage } from 'ui/storage';
+import { data } from 'plugins/data/setup';
+import { getDefaultQueryLanguage } from '../lib/get_default_query_language';
+const { QueryBarInput } = data.query.ui;
+const localStorage = new Storage(window.localStorage);
+export class TablePanelConfig extends Component {
   constructor(props) {
     super(props);
     this.state = { selectedTab: 'data' };
@@ -64,7 +67,7 @@ class TablePanelConfig extends Component {
     this.setState({ selectedTab });
   }
 
-  handlePivotChange = (selectedOption) => {
+  handlePivotChange = selectedOption => {
     const { fields, model } = this.props;
     const pivotId = get(selectedOption, '[0].value', null);
     const field = fields[model.index_pattern].find(field => field.name === pivotId);
@@ -72,13 +75,19 @@ class TablePanelConfig extends Component {
 
     this.props.onChange({
       pivot_id: pivotId,
-      pivot_type: pivotType
+      pivot_type: pivotType,
     });
   };
 
   render() {
     const { selectedTab } = this.state;
-    const defaults = { drilldown_url: '', filter: '', pivot_label: '', pivot_rows: 10, pivot_type: '' };
+    const defaults = {
+      drilldown_url: '',
+      filter: { query: '', language: getDefaultQueryLanguage() },
+      pivot_label: '',
+      pivot_rows: 10,
+      pivot_type: '',
+    };
     const model = { ...defaults, ...this.props.model };
     const handleTextChange = createTextHandler(this.props.onChange);
     const htmlId = htmlIdGenerator();
@@ -102,10 +111,12 @@ class TablePanelConfig extends Component {
                 <EuiFlexItem data-test-subj="groupByField">
                   <EuiFormRow
                     id={htmlId('field')}
-                    label={(<FormattedMessage
-                      id="tsvb.table.dataTab.groupByFieldLabel"
-                      defaultMessage="Group by field"
-                    />)}
+                    label={
+                      <FormattedMessage
+                        id="tsvb.table.dataTab.groupByFieldLabel"
+                        defaultMessage="Group by field"
+                      />
+                    }
                   >
                     <FieldSelect
                       fields={this.props.fields}
@@ -119,10 +130,12 @@ class TablePanelConfig extends Component {
                 <EuiFlexItem>
                   <EuiFormRow
                     id={htmlId('pivotLabelInput')}
-                    label={(<FormattedMessage
-                      id="tsvb.table.dataTab.columnLabel"
-                      defaultMessage="Column label"
-                    />)}
+                    label={
+                      <FormattedMessage
+                        id="tsvb.table.dataTab.columnLabel"
+                        defaultMessage="Column label"
+                      />
+                    }
                     fullWidth
                   >
                     <EuiFieldText
@@ -136,10 +149,9 @@ class TablePanelConfig extends Component {
                 <EuiFlexItem grow={false}>
                   <EuiFormRow
                     id={htmlId('pivotRowsInput')}
-                    label={(<FormattedMessage
-                      id="tsvb.table.dataTab.rowsLabel"
-                      defaultMessage="Rows"
-                    />)}
+                    label={
+                      <FormattedMessage id="tsvb.table.dataTab.rowsLabel" defaultMessage="Rows" />
+                    }
                   >
                     {/*
                       EUITODO: The following input couldn't be converted to EUI because of type mis-match.
@@ -172,25 +184,24 @@ class TablePanelConfig extends Component {
           <EuiPanel>
             <EuiTitle size="s">
               <span>
-                <FormattedMessage
-                  id="tsvb.table.optionsTab.dataLabel"
-                  defaultMessage="Data"
-                />
+                <FormattedMessage id="tsvb.table.optionsTab.dataLabel" defaultMessage="Data" />
               </span>
             </EuiTitle>
             <EuiSpacer size="m" />
             <EuiFormRow
               id={htmlId('drilldownInput')}
-              label={(<FormattedMessage
-                id="tsvb.table.optionsTab.itemUrlLabel"
-                defaultMessage="Item url"
-              />)}
+              label={
+                <FormattedMessage
+                  id="tsvb.table.optionsTab.itemUrlLabel"
+                  defaultMessage="Item url"
+                />
+              }
               helpText={
                 <span>
                   <FormattedMessage
                     id="tsvb.table.optionsTab.itemUrlHelpText"
                     defaultMessage="This supports mustache templating. {key} is set to the term."
-                    values={{ key: (<EuiCode>{'{{key}}'}</EuiCode>) }}
+                    values={{ key: <EuiCode>{'{{key}}'}</EuiCode> }}
                   />
                 </span>
               }
@@ -215,16 +226,25 @@ class TablePanelConfig extends Component {
               <EuiFlexItem>
                 <EuiFormRow
                   id={htmlId('panelFilterInput')}
-                  label={(<FormattedMessage
-                    id="tsvb.table.optionsTab.panelFilterLabel"
-                    defaultMessage="Panel filter"
-                  />)}
+                  label={
+                    <FormattedMessage
+                      id="tsvb.table.optionsTab.panelFilterLabel"
+                      defaultMessage="Panel filter"
+                    />
+                  }
                   fullWidth
                 >
-                  <EuiFieldText
-                    onChange={handleTextChange('filter')}
-                    value={model.filter}
-                    fullWidth
+                  <QueryBarInput
+                    query={{
+                      language: model.filter.language
+                        ? model.filter.language
+                        : getDefaultQueryLanguage(),
+                      query: model.filter.query || '',
+                    }}
+                    onChange={filter => this.props.onChange({ filter })}
+                    appName={'VisEditor'}
+                    indexPatterns={[model.index_pattern || model.default_index_pattern]}
+                    store={localStorage}
                   />
                 </EuiFormRow>
               </EuiFlexItem>
@@ -251,19 +271,10 @@ class TablePanelConfig extends Component {
     return (
       <div>
         <EuiTabs size="s">
-          <EuiTab
-            isSelected={selectedTab === 'data'}
-            onClick={() => this.switchTab('data')}
-          >
-            <FormattedMessage
-              id="tsvb.table.dataTab.columnsButtonLabel"
-              defaultMessage="Columns"
-            />
+          <EuiTab isSelected={selectedTab === 'data'} onClick={() => this.switchTab('data')}>
+            <FormattedMessage id="tsvb.table.dataTab.columnsButtonLabel" defaultMessage="Columns" />
           </EuiTab>
-          <EuiTab
-            isSelected={selectedTab === 'options'}
-            onClick={() => this.switchTab('options')}
-          >
+          <EuiTab isSelected={selectedTab === 'options'} onClick={() => this.switchTab('options')}>
             <FormattedMessage
               id="tsvb.table.optionsTab.panelOptionsButtonLabel"
               defaultMessage="Panel options"
@@ -274,7 +285,6 @@ class TablePanelConfig extends Component {
       </div>
     );
   }
-
 }
 
 TablePanelConfig.propTypes = {
@@ -283,5 +293,3 @@ TablePanelConfig.propTypes = {
   onChange: PropTypes.func,
   visData$: PropTypes.object,
 };
-
-export default TablePanelConfig;
