@@ -17,10 +17,10 @@
  * under the License.
  */
 
-export default {
+export const COLORS = {
   lineColor: 'rgba(105,112,125,0.2)',
   textColor: 'rgba(0,0,0,0.4)',
   textColorReversed: 'rgba(255,255,255,0.5)',
   valueColor: 'rgba(0,0,0,0.7)',
-  valueColorReversed: 'rgba(255,255,255,0.8)'
+  valueColorReversed: 'rgba(255,255,255,0.8)',
 };
