@@ -47,6 +47,7 @@ import { initSavedObjectClient } from './api/saved_object_client';
 import { initChromeBasePathApi } from './api/base_path';
 import { initChromeInjectedVarsApi } from './api/injected_vars';
 import { initHelpExtensionApi } from './api/help_extension';
+import { npStart } from '../new_platform';
 
 export const chrome = {};
 const internals = _.defaults(
@@ -80,6 +81,8 @@ initChromeControlsApi(chrome);
 templateApi(chrome, internals);
 initChromeThemeApi(chrome);
 
+npStart.core.chrome.setAppTitle(chrome.getAppTitle());
+
 const waitForBootstrap = new Promise(resolve => {
   chrome.bootstrap = function (targetDomElement) {
     // import chrome nav controls and hacks now so that they are executed after
@@ -92,8 +95,10 @@ const waitForBootstrap = new Promise(resolve => {
     document.body.setAttribute('id', `${internals.app.id}-app`);
 
     chrome.setupAngular();
-    targetDomElement.setAttribute('id', 'kibana-body');
+    // targetDomElement.setAttribute('id', 'kibana-body');
     targetDomElement.setAttribute('kbn-chrome', 'true');
+    targetDomElement.setAttribute('ng-class', '{ \'hidden-chrome\': !chrome.getVisible() }');
+    targetDomElement.className = 'app-wrapper';
     angular.bootstrap(targetDomElement, ['kibana']);
     resolve(targetDomElement);
   };
