@@ -1,4 +1,4 @@
-'use strict';
+"use strict";
 
 /*
  * Licensed to Elasticsearch B.V. under one or more contributor
@@ -18,11 +18,10 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 require('brace');
+
 require('brace/mode/json');
+
 require('../node_modules/@elastic/ui-ace/ui-ace');
 
-require('ui/modules').get('kibana', ['ui.ace']);
-
 module.exports = window.ace;
\ No newline at end of file
